==> kubernetes-model-apiextensions-4.12.0-sources.jar: annotations/io/fabric8/kubernetes/api/model/apiextensions/v1beta1/CustomResourceDefinitionFluent.java <==
package io.fabric8.kubernetes.api.model.apiextensions.v1beta1;

import io.fabric8.kubernetes.api.model.ObjectMeta;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import io.fabric8.kubernetes.api.model.ObjectMetaBuilder;
import java.lang.StringBuffer;
import io.fabric8.kubernetes.api.model.ObjectMetaFluent;
import java.lang.Deprecated;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

public interface CustomResourceDefinitionFluent<A extends io.fabric8.kubernetes.api.model.apiextensions.v1beta1.CustomResourceDefinitionFluent<A>> extends Fluent<A> {


    public String getApiVersion();
    public A withApiVersion(String apiVersion);
    public Boolean hasApiVersion();
    public A withNewApiVersion(String arg1);
    public A withNewApiVersion(StringBuilder arg1);
    public A withNewApiVersion(StringBuffer arg1);
    public String getKind();
    public A withKind(String kind);
    public Boolean hasKind();
    public A withNewKind(String arg1);
    public A withNewKind(StringBuilder arg1);
    public A withNewKind(StringBuffer arg1);
    
/**
 * This method has been deprecated, please use method buildMetadata instead.
 * @return The buildable object.
 */
@Deprecated public ObjectMeta getMetadata();
    public ObjectMeta buildMetadata();
    public A withMetadata(ObjectMeta metadata);
    public Boolean hasMetadata();
    public CustomResourceDefinitionFluent.MetadataNested<A> withNewMetadata();
    public CustomResourceDefinitionFluent.MetadataNested<A> withNewMetadataLike(ObjectMeta item);
    public CustomResourceDefinitionFluent.MetadataNested<A> editMetadata();
    public CustomResourceDefinitionFluent.MetadataNested<A> editOrNewMetadata();
    public CustomResourceDefinitionFluent.MetadataNested<A> editOrNewMetadataLike(ObjectMeta item);
    
/**
 * This method has been deprecated, please use method buildSpec instead.
 * @return The buildable object.
 */
@Deprecated public io.fabric8.kubernetes.api.model.apiextensions.v1beta1.CustomResourceDefinitionSpec getSpec();
    public io.fabric8.kubernetes.api.model.apiextensions.v1beta1.CustomResourceDefinitionSpec buildSpec();
    public A withSpec(io.fabric8.kubernetes.api.model.apiextensions.v1beta1.CustomResourceDefinitionSpec spec);
    public Boolean hasSpec();
    public CustomResourceDefinitionFluent.SpecNested<A> withNewSpec();
    public CustomResourceDefinitionFluent.SpecNested<A> withNewSpecLike(io.fabric8.kubernetes.api.model.apiextensions.v1beta1.CustomResourceDefinitionSpec item);
    public CustomResourceDefinitionFluent.SpecNested<A> editSpec();
    public CustomResourceDefinitionFluent.SpecNested<A> editOrNewSpec();
    public CustomResourceDefinitionFluent.SpecNested<A> editOrNewSpecLike(io.fabric8.kubernetes.api.model.apiextensions.v1beta1.CustomResourceDefinitionSpec item);
    
/**
 * This method has been deprecated, please use method buildStatus instead.
 * @return The buildable object.
 */
@Deprecated public io.fabric8.kubernetes.api.model.apiextensions.v1beta1.CustomResourceDefinitionStatus getStatus();
    public io.fabric8.kubernetes.api.model.apiextensions.v1beta1.CustomResourceDefinitionStatus buildStatus();
    public A withStatus(io.fabric8.kubernetes.api.model.apiextensions.v1beta1.CustomResourceDefinitionStatus status);
    public Boolean hasStatus();
    public CustomResourceDefinitionFluent.StatusNested<A> withNewStatus();
    public CustomResourceDefinitionFluent.StatusNested<A> withNewStatusLike(io.fabric8.kubernetes.api.model.apiextensions.v1beta1.CustomResourceDefinitionStatus item);
    public CustomResourceDefinitionFluent.StatusNested<A> editStatus();
    public CustomResourceDefinitionFluent.StatusNested<A> editOrNewStatus();
    public CustomResourceDefinitionFluent.StatusNested<A> editOrNewStatusLike(io.fabric8.kubernetes.api.model.apiextensions.v1beta1.CustomResourceDefinitionStatus item);
    public interface MetadataNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,ObjectMetaFluent<CustomResourceDefinitionFluent.MetadataNested<N>> {

        public N and();
        public N endMetadata();    }


    public interface SpecNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,io.fabric8.kubernetes.api.model.apiextensions.v1beta1.CustomResourceDefinitionSpecFluent<CustomResourceDefinitionFluent.SpecNested<N>> {

        public N and();
        public N endSpec();    }


    public interface StatusNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,io.fabric8.kubernetes.api.model.apiextensions.v1beta1.CustomResourceDefinitionStatusFluent<CustomResourceDefinitionFluent.StatusNested<N>> {

        public N and();
        public N endStatus();    }


}

==> kubernetes-model-apiextensions-5.3.0-sources.jar: annotations/io/fabric8/kubernetes/api/model/apiextensions/v1beta1/CustomResourceDefinitionFluent.java <==
package io.fabric8.kubernetes.api.model.apiextensions.v1beta1;

import io.fabric8.kubernetes.api.model.ObjectMeta;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import io.fabric8.kubernetes.api.model.ObjectMetaBuilder;
import java.lang.StringBuffer;
import io.fabric8.kubernetes.api.model.ObjectMetaFluent;
import java.lang.Deprecated;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

public interface CustomResourceDefinitionFluent<A extends io.fabric8.kubernetes.api.model.apiextensions.v1beta1.CustomResourceDefinitionFluent<A>> extends Fluent<A> {


    public String getApiVersion();
    public A withApiVersion(String apiVersion);
    public Boolean hasApiVersion();
    public A withNewApiVersion(StringBuilder arg1);
    public A withNewApiVersion(int[] arg1,int arg2,int arg3);
    public A withNewApiVersion(char[] arg1);
    public A withNewApiVersion(StringBuffer arg1);
    public A withNewApiVersion(byte[] arg1,int arg2);
    public A withNewApiVersion(byte[] arg1);
    public A withNewApiVersion(char[] arg1,int arg2,int arg3);
    public A withNewApiVersion(byte[] arg1,int arg2,int arg3);
    public A withNewApiVersion(byte[] arg1,int arg2,int arg3,int arg4);
    public A withNewApiVersion(String arg1);
    public String getKind();
    public A withKind(String kind);
    public Boolean hasKind();
    public A withNewKind(StringBuilder arg1);
    public A withNewKind(int[] arg1,int arg2,int arg3);
    public A withNewKind(char[] arg1);
    public A withNewKind(StringBuffer arg1);
    public A withNewKind(byte[] arg1,int arg2);
    public A withNewKind(byte[] arg1);
    public A withNewKind(char[] arg1,int arg2,int arg3);
    public A withNewKind(byte[] arg1,int arg2,int arg3);
    public A withNewKind(byte[] arg1,int arg2,int arg3,int arg4);
    public A withNewKind(String arg1);
    
/**
 * This method has been deprecated, please use method buildMetadata instead.
 * @return The buildable object.
 */
@Deprecated public ObjectMeta getMetadata();
    public ObjectMeta buildMetadata();
    public A withMetadata(ObjectMeta metadata);
    public Boolean hasMetadata();
    public CustomResourceDefinitionFluent.MetadataNested<A> withNewMetadata();
    public CustomResourceDefinitionFluent.MetadataNested<A> withNewMetadataLike(ObjectMeta item);
    public CustomResourceDefinitionFluent.MetadataNested<A> editMetadata();
    public CustomResourceDefinitionFluent.MetadataNested<A> editOrNewMetadata();
    public CustomResourceDefinitionFluent.MetadataNested<A> editOrNewMetadataLike(ObjectMeta item);
    
/**
 * This method has been deprecated, please use method buildSpec instead.
 * @return The buildable object.
 */
@Deprecated public io.fabric8.kubernetes.api.model.apiextensions.v1beta1.CustomResourceDefinitionSpec getSpec();
    public io.fabric8.kubernetes.api.model.apiextensions.v1beta1.CustomResourceDefinitionSpec buildSpec();
    public A withSpec(io.fabric8.kubernetes.api.model.apiextensions.v1beta1.CustomResourceDefinitionSpec spec);
    public Boolean hasSpec();
    public CustomResourceDefinitionFluent.SpecNested<A> withNewSpec();
    public CustomResourceDefinitionFluent.SpecNested<A> withNewSpecLike(io.fabric8.kubernetes.api.model.apiextensions.v1beta1.CustomResourceDefinitionSpec item);
    public CustomResourceDefinitionFluent.SpecNested<A> editSpec();
    public CustomResourceDefinitionFluent.SpecNested<A> editOrNewSpec();
    public CustomResourceDefinitionFluent.SpecNested<A> editOrNewSpecLike(io.fabric8.kubernetes.api.model.apiextensions.v1beta1.CustomResourceDefinitionSpec item);
    
/**
 * This method has been deprecated, please use method buildStatus instead.
 * @return The buildable object.
 */
@Deprecated public io.fabric8.kubernetes.api.model.apiextensions.v1beta1.CustomResourceDefinitionStatus getStatus();
    public io.fabric8.kubernetes.api.model.apiextensions.v1beta1.CustomResourceDefinitionStatus buildStatus();
    public A withStatus(io.fabric8.kubernetes.api.model.apiextensions.v1beta1.CustomResourceDefinitionStatus status);
    public Boolean hasStatus();
    public CustomResourceDefinitionFluent.StatusNested<A> withNewStatus();
    public CustomResourceDefinitionFluent.StatusNested<A> withNewStatusLike(io.fabric8.kubernetes.api.model.apiextensions.v1beta1.CustomResourceDefinitionStatus item);
    public CustomResourceDefinitionFluent.StatusNested<A> editStatus();
    public CustomResourceDefinitionFluent.StatusNested<A> editOrNewStatus();
    public CustomResourceDefinitionFluent.StatusNested<A> editOrNewStatusLike(io.fabric8.kubernetes.api.model.apiextensions.v1beta1.CustomResourceDefinitionStatus item);
    public interface MetadataNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,ObjectMetaFluent<CustomResourceDefinitionFluent.MetadataNested<N>> {

            public N and();
            public N endMetadata();    }


    public interface SpecNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,io.fabric8.kubernetes.api.model.apiextensions.v1beta1.CustomResourceDefinitionSpecFluent<CustomResourceDefinitionFluent.SpecNested<N>> {

            public N and();
            public N endSpec();    }


    public interface StatusNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,io.fabric8.kubernetes.api.model.apiextensions.v1beta1.CustomResourceDefinitionStatusFluent<CustomResourceDefinitionFluent.StatusNested<N>> {

            public N and();
            public N endStatus();    }


}
